@@ -18,22 +18,22 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
+
 #include "LogFile.h"
 
 #include <stdio.h>
 #include <sys/types.h>
 
+#include <QDebug>
+#include <QDialog>
 #include <QPushButton>
 #include <QRegExp>
-
 #include <QListWidget>
 #include <QHBoxLayout>
-#include <kfontdialog.h>
-#include <kdebug.h>
-#include <KDialog>
+
 #include <KLocalizedString>
+#include <KNotification>
 #include <kcolorbutton.h>
-#include <knotification.h>
 #include "StyleEngine.h"
 
 #include "ui_LogFileSettings.h"
@@ -43,7 +43,7 @@
 LogFile::LogFile(QWidget *parent, const QString& title, SharedSettings *workSheetSettings)
 	: KSGRD::SensorDisplay(parent, title, workSheetSettings)
 {
-	kDebug() << "Making sensor logger";
+    qDebug() << "Making sensor logger";
 	logFileID= 0;
 	lfs = NULL;
 	QLayout *layout = new QHBoxLayout(this);
@@ -89,11 +89,15 @@ void LogFile::configureSettings(void)
 
 	lfs = new Ui_LogFileSettings;
 	Q_CHECK_PTR(lfs);
-	KDialog dlg;
-	dlg.setCaption( i18n("File logging settings") );
-	dlg.setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
+    QDialog dlg;
+    dlg.setWindowTitle( i18n("File logging settings") );
+    QWidget *mainWidget = new QWidget( this );
 
-	lfs->setupUi(dlg.mainWidget());
+    lfs->setupUi(mainWidget);
+
+    QVBoxLayout *vlayout = new QVBoxLayout(this);
+    vlayout->addWidget(mainWidget);
+    dlg.setLayout(vlayout);
 
 	lfs->fgColor->setColor(cgroup.color( QPalette::Text ));
 	lfs->fgColor->setText(i18n("Foreground color:"));
@@ -103,15 +107,15 @@ void LogFile::configureSettings(void)
 	lfs->ruleList->addItems(filterRules);
 	lfs->title->setText(title());
 
-	connect(&dlg, &KDialog::okClicked, &dlg, &KDialog::accept);
-	connect(&dlg, &KDialog::applyClicked, this, &LogFile::applySettings);
+    connect(lfs->buttonBox, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
+    connect(lfs->buttonBox, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
 
 	connect(lfs->addButton, &QPushButton::clicked, this, &LogFile::settingsAddRule);
 	connect(lfs->deleteButton, &QPushButton::clicked, this, &LogFile::settingsDeleteRule);
 	connect(lfs->changeButton, &QPushButton::clicked, this, &LogFile::settingsChangeRule);
 	connect(lfs->ruleList, &QListWidget::currentRowChanged, this, &LogFile::settingsRuleListSelected);
-	connect(lfs->ruleText, &KLineEdit::returnPressed, this, &LogFile::settingsAddRule);
-	connect(lfs->ruleText, &KLineEdit::textChanged, this, &LogFile::settingsRuleTextChanged);
+    connect(lfs->ruleText, &QLineEdit::returnPressed, this, &LogFile::settingsAddRule);
+    connect(lfs->ruleText, &QLineEdit::textChanged, this, &LogFile::settingsRuleTextChanged);
 
 	settingsRuleListSelected(lfs->ruleList->currentRow());
 	settingsRuleTextChanged();
